package com.ruoyi.interfaces.service;

import java.util.List;
import com.ruoyi.interfaces.domain.MdDataSetFile;

/**
 * 文件数据集Service接口
 * 
 * @author 朱得糠
 * @date 2025-09-02
 */
public interface IMdDataSetFileService 
{
    /**
     * 查询文件数据集
     * 
     * @param id 文件数据集主键
     * @return 文件数据集
     */
    public MdDataSetFile selectMdDataSetFileByDcCode(String id);

    /**
     * 查询文件数据集列表
     * 
     * @param mdDataSetFile 文件数据集
     * @return 文件数据集集合
     */
    public List<MdDataSetFile> selectMdDataSetFileList(MdDataSetFile mdDataSetFile);

    /**
     * 新增文件数据集
     * 
     * @param mdDataSetFile 文件数据集
     * @return 结果
     */
    public int insertMdDataSetFile(MdDataSetFile mdDataSetFile);

    /**
     * 修改文件数据集
     * 
     * @param mdDataSetFile 文件数据集
     * @return 结果
     */
    public int updateMdDataSetFile(MdDataSetFile mdDataSetFile);

    /**
     * 批量删除文件数据集
     * 
     * @param ids 需要删除的文件数据集主键集合
     * @return 结果
     */
    public int deleteMdDataSetFileByIds(Long[] ids);

    /**
     * 删除文件数据集信息
     * 
     * @param id 文件数据集主键
     * @return 结果
     */
    public int deleteMdDataSetFileById(Long id);

    int deleteMdDataSetFileByDcCode(String dcCode);
}
